Learn R Programming

icaOcularCorrection (version 1.3)

defineElectrodeSet.fnc: Generate a vector of channel names and plotting information.

Description

Generates a vector of channel names of a specific kind of cap ("Biosemi", "Easy Cap") as well as information for plotting namely, panel skips, x and y ticks, x and y coordinates, and a plotting matrix.

Usage

defineElectrodeSet.fnc(which.cap = "biosemi.32", 
bottom.eye = "BE")

Arguments

which.cap
One of "easy.cap.28", "easy.cap.64.partial", "easy.cap.64.full", or "biosemi.32". Defaults to "biosemi.32".
bottom.eye
Adds the specified EOG channel to the vector of EEG channels. Defaults to "BE", i.e., bottom eye EOG. Can be set to any other EOG channel (e.g., "TE", "LC", "RC", etc.). Can also be "NA", in

Value

  • electrodesA vector of EEG channel names.
  • xticksA vector of comprised of "s" or "n" indicating, for each channel in the electrodes vector, the x-axis should be drawn.
  • yticksA vector of comprised of "s" or "n" indicating, for each channel in the electrodes vector, the y-axis should be drawn.
  • skipsA named numeric vector indicating how many panels should be left blank before plotting the specific EEG channel (e.g., draw 2 blank panels before plotting channel O1 in the "biosemi.32" cap setup).
  • pmatrixA matrix of NAs with number of rows equal to the number of channel rows on cap (e.g., 9 rows from Fp1 to O1 in "biosemi.32" setup) and number of columns equal to the number of channel columns on cap (e.g., 5 columns from T7 to T8 in "biosemi.32" setup).
  • xcordsA named vector indicating the column number to plot a specific EEG channel (e.g., plot channel Fp1 in second panel; plot channel Fp2 in fourth panel).
  • ycordsA named vector indicating the row number to plot a specific EEG channel (e.g., plot channels Fp1 and Fp2 in first row; plot channel Fz in third row).
  • cap.nameThe name of the cap setup used.

concept

  • EEG
  • electro-encephalogram
  • electroencephalogram
  • ERP
  • event-related potentials
  • event related potentials

See Also

eeg; den; batch.icaDEN.fnc; mc.batch.icaDEN.fnc; icaDEN.fnc

Examples

Run this code
defineElectrodeSet.fnc(which.cap = "biosemi.32", 
     bottom.eye = NA)

Run the code above in your browser using DataLab