| Package: |
| icaOcularCorrection |
| Type: |
| Package |
| Version: |
| 3.0.0 |
| Date: |
| 2013-07-12 |
| License: |
| GPL-2 |
| LazyLoad: |
| yes |
browseVignettes(package = "icaOcularCorrection"). This will open a web browser with links to the vignette PDF as well as a plain-text R file containing the code used in the vignette. The vignette files, both the PDF and the Rnw sources document, are located in the doc directory of an installed package (inst/doc for an uninstalled package tarball). The PDF, R, and Rnw versions of the vignette are located in paste(system.file(package = "icaOcularCorrection"), "doc/", sep = "/"). See Hyvarinen, Aapo & Oja, Erkki. (1999). Independent Component Analysis: A Tutorial. Available at http://cis.legacy.ics.tkk.fi/aapo/papers/IJCNN99_tutorialweb/.
fastICA;
icac;
mwd.thrsh;
plot_avgba;
plot_trba;
plot_nic;
plot_tric;
summary.icac;
topo_ic;
update.icac.
### See vignette for examples.
Run the code above in your browser using DataLab