topo_ic(x, ic, coords = c("bosemi.32","egi.129",
"neuromag.306.mag", "neuromag.306.plan1", "neuromag.306.plan2"),
col = "topo", xlab="left to right", ylab="back to front",
k = NULL, bs = "cr", too.far = NULL, ...)icac object as returned by the function of the same name.NULL, i.e., its value depends on the
coordinate system. See te from package mgcv for details.smooth.terms from
package mgcv for an over view of what is available.too.far determines what is too far.
Defaults to NULL, i.e., its value depends on the coordinate
system. NA to disable.vis.gam from
packages mgcv.fastICA;
icac;
mwd.thrsh;
plot_avgba;
plot_trba;
plot_nic;
plot_tric;
summary.icac;
update.icac.
### See vignette for examples.
Run the code above in your browser using DataLab