icac.icac object as returned by the function of the same name and updates the correction as specified in argument what. Returns an icac object with the same slots as function icac does."update"(object, what, verbosity = 2,
...)icac object as returned by the function of the same name.method = "zero-out". In the second case, this argument should be a list containing named two-element vectors (one or more). The first element of each vector should be the number corresponding to the IC that will operated on; the second element should be the operation to perform on the whole IC (put back, "+", or zero-out, "-").0 turns this option off. Defaults to 2. Maximum value is 2.icac object with slots:
update.icac.proctime = TRUE when running function icac, a data frame with processing time information.fastICA;
icac;
mwd.thrsh;
plot_avgba;
plot_trba;
plot_nic;
plot_tric;
summary.icac;
topo_ic.
### See vignette for examples.
Run the code above in your browser using DataLab