"Biosemi", "Easy Cap") as well as information for plotting namely, panel skips, x and y ticks, x and y coordinates, and a plotting matrix.defineElectrodeSet.fnc(which.cap = "biosemi.32",
bottom.eye = "BE")"easy.cap.28", "easy.cap.64.partial", "easy.cap.64.full", or "biosemi.32". Defaults to "biosemi.32"."BE", i.e., bottom eye EOG. Can be set to any other EOG channel (e.g., "TE", "LC", "RC", etc.). Can also be "NA", in"s" or "n" indicating, for each channel in the electrodes vector, the x-axis should be drawn."s" or "n" indicating, for each channel in the electrodes vector, the y-axis should be drawn."biosemi.32" cap setup)."biosemi.32" setup) and number of columns equal to the number of channel columns on cap (e.g., 5 columns from T7 to T8 in "biosemi.32" setup).eeg;
den;
batch.icaDEN.fnc;
mc.batch.icaDEN.fnc;
icaDEN.fncdefineElectrodeSet.fnc(which.cap = "biosemi.32",
bottom.eye = NA)Run the code above in your browser using DataLab